"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Api = exports.ApiError = void 0;
const axios_1 = require("axios");
const debug = require("debug");
class ApiError extends Error {
}
exports.ApiError = ApiError;
class Api {
    constructor(token) {
        this.token = token;
        this.log = debug("tg-io:api");
        this.baseUrl = "https://api.telegram.org/bot";
    }
    async callMethod(method, params) {
        let response;
        try {
            response = await axios_1.default.post(`${this.baseUrl}${this.token}/${method}`, params);
        }
        catch (reqError) {
            if (reqError instanceof axios_1.AxiosError) {
                let error = new ApiError(reqError.message);
                error.code = reqError.response.data.code;
                error.method = method;
                error.params = JSON.stringify(params, null, 2);
                throw error;
            }
            throw reqError;
        }
        finally {
            this.log(`${method} ${response ? "OK" : "ERROR"}`);
        }
        return response.data;
    }
}
exports.Api = Api;
