"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PollingState = exports.Polling = void 0;
const debug = require("debug");
class Polling {
    constructor(api) {
        this.api = api;
        this.log = debug("tg-io:polling");
        this.state = PollingState.NotLaunched;
    }
    async start(handler) {
        if (this.state === PollingState.Working)
            return;
        this.log("started");
        let offset = null;
        this.state = PollingState.Working;
        while (this.state === PollingState.Working) {
            let updates = await this.api.callMethod("getUpdates", (offset === null ? {} : { offset }));
            for (let update of updates.result) {
                await handler.handle(update);
                offset = update.update_id + 1;
            }
        }
    }
    stop() {
        if (this.state !== PollingState.Working)
            return;
        this.log("stopped");
        this.state = PollingState.Stopped;
    }
}
exports.Polling = Polling;
var PollingState;
(function (PollingState) {
    PollingState[PollingState["NotLaunched"] = 0] = "NotLaunched";
    PollingState[PollingState["Working"] = 1] = "Working";
    PollingState[PollingState["Stopped"] = 2] = "Stopped";
    PollingState[PollingState["Failed"] = 3] = "Failed";
})(PollingState = exports.PollingState || (exports.PollingState = {}));
