"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UpdateHandler = void 0;
const CallbackQueryContext_1 = require("./contexts/CallbackQueryContext");
const MessageContext_1 = require("./contexts/MessageContext");
class UpdateHandler {
    constructor(api) {
        this.api = api;
        this.contextCtorStorage = {
            message: MessageContext_1.MessageContext,
            callback_query: CallbackQueryContext_1.CallbackQueryContext
        };
        this.baseHandler = null;
        this.updates = {};
    }
    async handle(update) {
        var _a;
        let middlewareState = HandlerMiddlewareState.Next;
        let nextMiddlewareFn = () => {
            middlewareState = HandlerMiddlewareState.Next;
        };
        await ((_a = this === null || this === void 0 ? void 0 : this.baseHandler) === null || _a === void 0 ? void 0 : _a.call(this, update, nextMiddlewareFn));
        if (middlewareState !== HandlerMiddlewareState.Next)
            return;
        for (let updateHandler of Object.entries(this.updates)
            .filter(([key]) => Object.keys(update).includes(key))
            .flatMap(([_, body]) => body)) {
            if (middlewareState === HandlerMiddlewareState.Next) {
                middlewareState = HandlerMiddlewareState.Stop;
                await updateHandler(update, nextMiddlewareFn);
                continue;
            }
            break;
        }
    }
    setContext(event, ctor) {
        this.contextCtorStorage[event] = ctor;
    }
    use(handler) {
        this.baseHandler = handler;
    }
    onUpdate(updateKind, handler) {
        if (!this.updates.hasOwnProperty(updateKind))
            this.updates[updateKind] = [];
        this.updates[updateKind].push((upd, next) => handler(upd[updateKind], next));
    }
    hearCallbackQuery(match, handler) {
        this.onUpdate("callback_query", this.hearEvent(match, handler, this.contextCtorStorage.callback_query, "data"));
    }
    hearCommand(match, handler) {
        this.onUpdate("message", this.hearEvent(match, handler, this.contextCtorStorage.message, "text"));
    }
    hearEvent(match, handler, ctor, matchSouce) {
        return (upd, next) => {
            let content = upd === null || upd === void 0 ? void 0 : upd[matchSouce];
            let isMatched = ((typeof match === "string" && content === match) ||
                (Array.isArray(match) && match.some(t => t === content)) ||
                (match instanceof RegExp && match.test(content)));
            if (isMatched) {
                let evt = new ctor(this.api, upd);
                evt.match = match instanceof RegExp
                    ? content.match(match)
                    : [];
                return handler(evt, next);
            }
            return next();
        };
    }
    onMessageEvent(event, handler) {
        this.onUpdate("message", (upd, next) => upd.hasOwnProperty(event)
            ? handler(new this.contextCtorStorage.message(this.api, upd), next)
            : next());
    }
}
exports.UpdateHandler = UpdateHandler;
var HandlerMiddlewareState;
(function (HandlerMiddlewareState) {
    HandlerMiddlewareState[HandlerMiddlewareState["Next"] = 0] = "Next";
    HandlerMiddlewareState[HandlerMiddlewareState["Stop"] = 1] = "Stop";
})(HandlerMiddlewareState || (HandlerMiddlewareState = {}));
