"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Webhook = void 0;
const debug = require("debug");
const https = require("https");
const EventTransport_1 = require("./EventTransport");
const promises_1 = require("fs/promises");
class Webhook extends EventTransport_1.EventTransport {
    constructor(api, options) {
        super(api);
        this.options = options;
        this.log = debug("tg-io:webhook");
    }
    start(handler, port = 8443) {
        if (this.state === EventTransport_1.EventTransportState.Working)
            return;
        this.startServer(port);
        this.log(`started on ${port} port`);
        this.state = EventTransport_1.EventTransportState.Working;
    }
    stop() {
        if (this.state !== EventTransport_1.EventTransportState.Working)
            return;
        this.log("stopped");
        this.state = EventTransport_1.EventTransportState.Stopped;
    }
    async startServer(port) {
        let tls = this.options.tls
            ? {
                key: await (0, promises_1.readFile)(this.options.tls.key),
                cert: await (0, promises_1.readFile)(this.options.tls.cert)
            }
            : {};
        this.server = new https.Server(tls, (req, res) => {
            res.end();
            console.log(req);
        });
        this.server.listen(port);
    }
}
exports.Webhook = Webhook;
